from setuptools import setup


version = '0.1.3'


setup(name='pll',
      version=version,
      author='Beta Faccion',
      author_email='betafcc@gmail.com',
      packages=['pll'],
      install_requires=['tqdm'],
      url='https://github.com/betafcc/pll',
      download_url='https://github.com/betafcc/pll/tarball/v' + version,
      )
